import type { Pair } from '../nodes/Pair';
import type { StringifyContext } from './stringify';
export declare function stringifyPair({ key, value }: Readonly<Pair>, ctx: StringifyContext, onComment?: () => void, onChompKeep?: () => void): string;
